@@ -18,7 +18,6 @@ from pyqtgraph.graphicsItems.LegendItem import ItemSample
 from pyqtgraph.graphicsItems.ScatterPlotItem import drawSymbol
 from pyqtgraph.graphicsItems.ViewBox.ViewBoxMenu import ViewBoxMenu
 from pyqtgraph.parametertree import Parameter
-from typing_extensions import Literal
 from numpy.distutils.misc_util import is_sequence
 
 from utilitys.fns import nameFormatter, pascalCaseToTitle, params_flattened, \
@@ -28,6 +27,7 @@ from utilitys.typeoverloads import FilePath
 from . import params
 from .constants import PrjEnums
 from .params.prjparam import PrjParam
+from .shims import typing_extensions as t_e
 
 # Taken directly from https://stackoverflow.com/a/20610786/9463643
 # Many things can cause this statement to fail
@@ -132,8 +132,8 @@ class ScrollableErrorDialog(QtWidgets.QDialog):
     def updateTxt():
       nonlocal showTrace
       if showTrace:
-        newText = msgWithTrace
-        msgLbl.setTextFormat(QtCore.Qt.PlainText)
+        newText = msgWithTrace.replace('\n', '<br>')
+        msgLbl.setTextFormat(QtCore.Qt.RichText)
       else:
         newLines = msgWithoutTrace.splitlines()
         allLines = []
@@ -440,7 +440,7 @@ class ButtonCollection(QtWidgets.QGroupBox):
       out.append(btn)
     return out
 
-_layoutTypes = t.Union[Literal['H'], Literal['V']]
+_layoutTypes = t.Union[t_e.Literal['H'], t_e.Literal['V']]
 class EasyWidget:
   def __init__(self, children: t.List[t.Union[QtWidgets.QWidget, EasyWidget]],
                layout: str=None, useSplitter=False, baseWidget: QtWidgets.QWidget=None):
